@@ -12,11 +12,12 @@ use Carp;
 use Digest::SHA qw/ sha1_hex /;
 use Guard ();
 
-our $VERSION              = "0.12";
-our $DEFAULT_EXPIRES      = 86400;
-our $RETRY_INTERVAL       = 0.5;
-our $BLOCKING_KEY_POSTFIX = ":wait";
-our $WAIT_QUEUE           = 0;
+our $VERSION                  = "0.13";
+our $DEFAULT_EXPIRES          = 86400;
+our $RETRY_INTERVAL           = 0.5;
+our $BLOCKING_KEY_POSTFIX     = ":wait";
+our $WAIT_QUEUE               = 0;
+our $WARN_LOCK_TIME_THRESHOLD = 0;
 
 use constant {
     EXIT_CODE_ERROR => 111,
@@ -89,9 +90,17 @@ sub lock_guard {
         wait    => $wait,
         expires => defined $expires ? $expires : $DEFAULT_EXPIRES,
     };
+    my $start = [ Time::HiRes::gettimeofday ];
     my $token = try_get_lock($redis, $opt, $key)
         or return;
+
     return Guard::guard {
+        my $elapsed = Time::HiRes::tv_interval($start);
+        if ($opt->{expires} < $elapsed) {
+            warnf "guard(token:%s) seems to be already expired. elasped %s sec", $token, $elapsed;
+        } elsif (0 < $WARN_LOCK_TIME_THRESHOLD && $WARN_LOCK_TIME_THRESHOLD < $elapsed) {
+            warnf "guard(token:%s) elasped %s sec", $token, $elapsed;
+        }
         release_lock($redis, $opt, $key, $token);
     };
 }
@@ -317,6 +326,24 @@ If $blocking is true, lock_guard will be blocked until getting a lock. Otherwise
 
 =back
 
+=head1 Variables
+
+=over 4
+
+=item B<$WAIT_QUEUE>
+
+Default: 0
+
+If set to 1, Use the Redis BLPOP command to wait for unlocking instead of periodical polling.
+
+=item B<$WARN_LOCK_TIME_THRESHOLD>
+
+Default: 0
+
+If set to number over 0, put a warnings message to stderr when a lock guard unlocked spent over that seconds.
+
+=back
+
 =head1 LICENSE
 
 Copyright (C) FUJIWARA Shunichiro.
@@ -329,4 +356,3 @@ it under the same terms as Perl itself.
 FUJIWARA Shunichiro E<lt>fujiwara.shunichiro@gmail.comE<gt>
 
 =cut
-
